@@ -1,8 +1,8 @@
 from abc import ABC
 from typing import Any, Optional, Dict, Generic
 
-from pm4py.algo.discovery.inductive.cuts.concurrency import ConcurrencyCut, ConcurrencyCutUVCL, T
-from pm4py.algo.discovery.inductive.dtypes.im_ds import IMDataStructureUVCL
+from pm4py.algo.discovery.inductive.cuts.concurrency import ConcurrencyCut, ConcurrencyCutUVCL, T, ConcurrencyCutDFG
+from pm4py.algo.discovery.inductive.dtypes.im_ds import IMDataStructureUVCL, IMDataStructureDFG
 from powl.objects.obj import StrictPartialOrder
 
 
@@ -16,3 +16,6 @@ class POWLConcurrencyCut(ConcurrencyCut, ABC, Generic[T]):
 class POWLConcurrencyCutUVCL(ConcurrencyCutUVCL, POWLConcurrencyCut[IMDataStructureUVCL]):
     pass
 
+class POWLConcurrencyCutDFG(ConcurrencyCutDFG, POWLConcurrencyCut[IMDataStructureDFG]):
+    pass
+
