@@ -169,8 +169,22 @@ def repr_powl(powl, viz, color_map, level, skip_order, loop_order):
             viz.node(this_node_id, label='', style='filled', fillcolor='black', shape='square',
                      width='0.3', height='0.3', fixedsize="true")
         else:
-            viz.node(this_node_id, str(powl.label), shape='box', fontsize=font_size, width=min_width, style='filled',
+            label = f"<{str(powl.label)}"
+            if powl._role is not None and powl._organization is not None:
+                # Add a label to the box
+                label += f"""<br/><font color="grey" point-size="10">({powl._organization}, {powl._role})</font><br/>"""
+            elif powl._organization is not None:
+                # Add a label to the box
+                label += f"""<br/><font color="grey" point-size="10">({powl._organization})</font><br/>"""
+            elif powl._role is not None:
+                # Add a label to the box
+                label += f"""<br/><font color="grey" point-size="10">({powl._role})</font><br/>"""
+            
+            label += ">"
+
+            viz.node(this_node_id, label, shape='box', fontsize=font_size, width=min_width, style='filled',
                      fillcolor=current_color)
+            
 
     elif isinstance(powl, StrictPartialOrder):
         transitive_reduction = powl.order.get_transitive_reduction()
